@@ -3,8 +3,8 @@
 
 #include <glib-object.h>
 
-/* enumerations from "preferences.h" */
-#include "preferences.h"
+/* enumerations from "/home/paolo/workspace/gthumb/extensions/pixbuf_savers/preferences.h" */
+#include "/home/paolo/workspace/gthumb/extensions/pixbuf_savers/preferences.h"
 GType
 gth_tiff_compression_get_type (void)
 {
