@@ -39,9 +39,17 @@ static const char *fixed_ui_info =
 "      <separator/>"
 "      <placeholder name='Folder_Actions'/>"
 "      <separator/>"
-"      <placeholder name='Misc_Actions'/>"
-"      <menu name='Export' action='ExportMenu'>"
+"      <menu name='Import' action='ImportMenu'>"
+"        <placeholder name='Misc_Actions'/>"
+"        <separator/>"
+"        <placeholder name='Web_Services'/>"
 "      </menu>"
+"      <menu name='Export' action='ExportMenu'>"
+"        <placeholder name='Web_Services'/>"
+"        <separator/>"
+"        <placeholder name='Misc_Actions'/>"
+"      </menu>"
+"      <placeholder name='Misc_Actions'/>"
 "      <separator/>"
 "      <menuitem action='File_CloseWindow'/>"
 "    </menu>"
