@@ -527,14 +527,15 @@ gth_extension_description_load_from_file (GthExtensionDescription *desc,
 
 	basename = g_file_get_basename (file);
 	desc->id = _g_uri_remove_extension (basename);
-	desc->name = g_key_file_get_string (key_file, "Extension", "Name", NULL);
-	desc->description = g_key_file_get_string (key_file, "Extension", "Description", NULL);
-	desc->version = g_key_file_get_string (key_file, "Extension", "Version", NULL);
-	desc->authors = g_key_file_get_string_list (key_file, "Extension", "Authors", NULL, NULL);
-	desc->copyright = g_key_file_get_string (key_file, "Extension", "Copyright", NULL);
+	desc->name = g_key_file_get_locale_string (key_file, "Extension", "Name", NULL, NULL);
+	desc->description = g_key_file_get_locale_string (key_file, "Extension", "Description", NULL, NULL);
+	desc->version = g_key_file_get_locale_string (key_file, "Extension", "Version", NULL, NULL);
+	desc->authors = g_key_file_get_locale_string_list (key_file, "Extension", "Authors", NULL, NULL, NULL);
+	desc->copyright = g_key_file_get_locale_string (key_file, "Extension", "Copyright", NULL, NULL);
 	desc->icon_name = g_key_file_get_string (key_file, "Extension", "Icon", NULL);
 	desc->url = g_key_file_get_string (key_file, "Extension", "URL", NULL);
 	desc->mandatory = g_key_file_get_boolean (key_file, "Extension", "Mandatory", NULL);
+	desc->hidden = g_key_file_get_boolean (key_file, "Extension", "Hidden", NULL);
 	desc->loader_type = g_key_file_get_string (key_file, "Loader", "Type", NULL);
 	desc->loader_file = g_key_file_get_string (key_file, "Loader", "File", NULL);
 	desc->loader_requires = g_key_file_get_string_list (key_file, "Loader", "Requires", NULL, NULL);
@@ -871,7 +872,8 @@ get_extension_optional_dependencies (GthExtensionManager     *manager,
 		dependencies = g_list_prepend (dependencies, extension_name);
 
 		other_description = g_hash_table_lookup (manager->priv->extensions, extension_name);
-		dependencies = g_list_concat (get_extension_optional_dependencies (manager, other_description), dependencies);
+		if (other_description != NULL)
+			dependencies = g_list_concat (get_extension_optional_dependencies (manager, other_description), dependencies);
 	}
 
 	return dependencies;
